#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_MAX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_MAX_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/max.hpp>

#endif
